@@ -17,14 +17,16 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-import TTY, UIBase
-availableUIs = {'TTY': TTY, 'UIBase': UIBase}
+import UIBase
+try:
+    import TTY
+except ImportError:
+    pass
 try:
     import Tkinter
 except ImportError:
     pass
 else:
     import Tk
-    availableUIs['Tk'] = Tk
 
 import detector
