@@ -1,5 +1,9 @@
 productname = 'OfflineIMAP'
-versionstr = "3.0.1"
+versionstr = "3.0.2"
+revno = long('$Rev: 135 $'[6:-2])
+revstr = "Rev %d" % revno
+datestr = '$Date: 2002-07-17T19:57:07 $'
+
 
 versionlist = versionstr.split(".")
 major = versionlist[0]
@@ -9,7 +13,8 @@ copyright = "Copyright (C) 2002 John Goerzen"
 author = "John Goerzen"
 author_email = "jgoerzen@complete.org"
 description = "Disconnected Universal IMAP Mail Synchronization/Reader Support"
-bigcopyright = "%(productname)s %(versionstr)s, %(copyright)s <%(author_email)s>" % locals()
+bigcopyright = """%(productname)s %(versionstr)s (%(revstr)s)
+%(copyright)s <%(author_email)s>""" % locals()
 
 banner = bigcopyright + """
 This software comes with ABSOLUTELY NO WARRANTY; see the file
